package javax.net.ssl;

import java.util.List;
import java.util.function.BiFunction;
import java.nio.ByteBuffer;

public abstract class SSLEngine
{
    private String peerHost;
    private int peerPort;
    
    protected SSLEngine() {
        this.peerHost = null;
        this.peerPort = -1;
    }
    
    protected SSLEngine(String peerHost, int peerPort) {
        this.peerHost = null;
        this.peerPort = -1;
        this.peerHost = peerHost;
        this.peerPort = peerPort;
    }
    
    public String getPeerHost() {
        return this.peerHost;
    }
    
    public int getPeerPort() {
        return this.peerPort;
    }
    
    public SSLEngineResult wrap(ByteBuffer byteBuffer, ByteBuffer byteBuffer2) throws SSLException {
        return this.wrap(new ByteBuffer[] { byteBuffer }, 0, 1, byteBuffer2);
    }
    
    public SSLEngineResult wrap(ByteBuffer[] array, ByteBuffer byteBuffer) throws SSLException {
        if (array == null) {
            throw new IllegalArgumentException("src == null");
        }
        return this.wrap(array, 0, array.length, byteBuffer);
    }
    
    public abstract SSLEngineResult wrap(ByteBuffer[] p0, int p1, int p2, ByteBuffer p3) throws SSLException;
    
    public SSLEngineResult unwrap(ByteBuffer byteBuffer, ByteBuffer byteBuffer2) throws SSLException {
        return this.unwrap(byteBuffer, new ByteBuffer[] { byteBuffer2 }, 0, 1);
    }
    
    public SSLEngineResult unwrap(ByteBuffer byteBuffer, ByteBuffer[] array) throws SSLException {
        if (array == null) {
            throw new IllegalArgumentException("dsts == null");
        }
        return this.unwrap(byteBuffer, array, 0, array.length);
    }
    
    public abstract SSLEngineResult unwrap(ByteBuffer p0, ByteBuffer[] p1, int p2, int p3) throws SSLException;
    
    public abstract Runnable getDelegatedTask();
    
    public abstract void closeInbound() throws SSLException;
    
    public abstract boolean isInboundDone();
    
    public abstract void closeOutbound();
    
    public abstract boolean isOutboundDone();
    
    public abstract String[] getSupportedCipherSuites();
    
    public abstract String[] getEnabledCipherSuites();
    
    public abstract void setEnabledCipherSuites(String[] p0);
    
    public abstract String[] getSupportedProtocols();
    
    public abstract String[] getEnabledProtocols();
    
    public abstract void setEnabledProtocols(String[] p0);
    
    public abstract SSLSession getSession();
    
    public SSLSession getHandshakeSession() {
        throw new UnsupportedOperationException();
    }
    
    public abstract void beginHandshake() throws SSLException;
    
    public abstract SSLEngineResult.HandshakeStatus getHandshakeStatus();
    
    public abstract void setUseClientMode(boolean p0);
    
    public abstract boolean getUseClientMode();
    
    public abstract void setNeedClientAuth(boolean p0);
    
    public abstract boolean getNeedClientAuth();
    
    public abstract void setWantClientAuth(boolean p0);
    
    public abstract boolean getWantClientAuth();
    
    public abstract void setEnableSessionCreation(boolean p0);
    
    public abstract boolean getEnableSessionCreation();
    
    public SSLParameters getSSLParameters() {
        SSLParameters sslParameters = new SSLParameters();
        sslParameters.setCipherSuites(this.getEnabledCipherSuites());
        sslParameters.setProtocols(this.getEnabledProtocols());
        if (this.getNeedClientAuth()) {
            sslParameters.setNeedClientAuth(true);
        }
        else if (this.getWantClientAuth()) {
            sslParameters.setWantClientAuth(true);
        }
        return sslParameters;
    }
    
    public void setSSLParameters(SSLParameters sslParameters) {
        String[] cipherSuites = sslParameters.getCipherSuites();
        if (cipherSuites != null) {
            this.setEnabledCipherSuites(cipherSuites);
        }
        String[] protocols = sslParameters.getProtocols();
        if (protocols != null) {
            this.setEnabledProtocols(protocols);
        }
        if (sslParameters.getNeedClientAuth()) {
            this.setNeedClientAuth(true);
        }
        else if (sslParameters.getWantClientAuth()) {
            this.setWantClientAuth(true);
        }
        else {
            this.setWantClientAuth(false);
        }
    }
    
    public String getApplicationProtocol() {
        throw new UnsupportedOperationException();
    }
    
    public String getHandshakeApplicationProtocol() {
        throw new UnsupportedOperationException();
    }
    
    public void setHandshakeApplicationProtocolSelector(BiFunction<SSLEngine, List<String>, String> biFunction) {
        throw new UnsupportedOperationException();
    }
    
    public BiFunction<SSLEngine, List<String>, String> getHandshakeApplicationProtocolSelector() {
        throw new UnsupportedOperationException();
    }
}
